==> xine-ui_0.9.8.orig.tar.gz: xine-ui-0.9.8/src/xitk/xine-toolkit/_config.h <==
/* 
 * Copyright (C) 2000-2001 the xine project
 * 
 * This file is part of xine, a unix video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * $Id: _config.h,v 1.1 2001/11/28 21:02:16 f1rmb Exp $
 *
 *
 */

#ifndef HAVE_XITK_CONFIG_H
#define HAVE_XITK_CONFIG_H

#include <stdio.h>

typedef struct {
  FILE        *fd;
  char        *cfgfilename;
  char        *ln;
  char         buf[256];
  
  struct {
    char      *fallback;
    char      *system;
  } fonts;

  struct {
    int        black;
    int        white;
    int        background;
    int        focus;
    int        select;
  } colors;

} xitk_config_t;


xitk_config_t *xitk_config_init(void);
void xitk_config_deinit(xitk_config_t *xtcf);
char *xitk_config_get_system_font(xitk_config_t *xtcf);
char *xitk_config_get_default_font(xitk_config_t *xtcf);
int xitk_config_get_black_color(xitk_config_t *xtcf);
int xitk_config_get_white_color(xitk_config_t *xtcf);
int xitk_config_get_background_color(xitk_config_t *xtcf);
int xitk_config_get_focus_color(xitk_config_t *xtcf);
int xitk_config_get_select_color(xitk_config_t *xtcf);

#endif

==> xine-ui-0.9.9.tar.gz: xine-ui-0.9.9/src/xitk/xine-toolkit/_config.h <==
/* 
 * Copyright (C) 2000-2002 the xine project
 * 
 * This file is part of xine, a unix video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * $Id: _config.h,v 1.3 2002/04/21 22:17:12 f1rmb Exp $
 *
 *
 */

#ifndef HAVE_XITK_CONFIG_H
#define HAVE_XITK_CONFIG_H

#include <stdio.h>

typedef struct {
  FILE             *fd;
  char             *cfgfilename;
  char             *ln;
  char              buf[256];
  
  struct {
    char           *fallback;
    char           *system;
  } fonts;

  struct {
    int             black;
    int             white;
    int             background;
    int             focus;
    int             select;
  } colors;

  struct {
    unsigned long   label_anim;
  } timers;

} xitk_config_t;


xitk_config_t *xitk_config_init(void);
void xitk_config_deinit(xitk_config_t *xtcf);
char *xitk_config_get_system_font(xitk_config_t *xtcf);
char *xitk_config_get_default_font(xitk_config_t *xtcf);
int xitk_config_get_black_color(xitk_config_t *xtcf);
int xitk_config_get_white_color(xitk_config_t *xtcf);
int xitk_config_get_background_color(xitk_config_t *xtcf);
int xitk_config_get_focus_color(xitk_config_t *xtcf);
int xitk_config_get_select_color(xitk_config_t *xtcf);
unsigned long xitk_config_get_timer_label_animation(xitk_config_t *xtcf);

#endif
